mailr10618 - /branches/bieri_gui/gui_bieri/about.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on February 02, 2010 - 16:41:
Author: bugman
Date: Tue Feb  2 16:41:39 2010
New Revision: 10618

URL: http://svn.gna.org/viewcvs/relax?rev=10618&view=rev
Log:
Converted About_relax into the About_base base class, and added About_relax 
which inherits from it.


Modified:
    branches/bieri_gui/gui_bieri/about.py

Modified: branches/bieri_gui/gui_bieri/about.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/bieri_gui/gui_bieri/about.py?rev=10618&r1=10617&r2=10618&view=diff
==============================================================================
--- branches/bieri_gui/gui_bieri/about.py (original)
+++ branches/bieri_gui/gui_bieri/about.py Tue Feb  2 16:41:39 2010
@@ -38,8 +38,8 @@
 
 
 
-class About_relax(wx.Dialog):
-    """The about relax dialog."""
+class About_base(wx.Dialog):
+    """The about dialog base class."""
 
     def __init__(self, *args, **kwds):
         """Build the dialog."""
@@ -48,7 +48,7 @@
         kwds["style"] = wx.BORDER_NONE
 
         # Execute the base class __init__() method.
-        super(self.__class__, self).__init__(*args, **kwds)
+        super(About_base, self).__init__(*args, **kwds)
 
         # Let the dialog be 
         self.Bind(wx.EVT_LEFT_DOWN, self.close, self)
@@ -66,6 +66,17 @@
 
         # Terminate the event.
         event.Skip()
+
+
+
+class About_relax(About_base):
+    """The about relax dialog."""
+
+    def __init__(self, *args, **kwds):
+        """Build the dialog."""
+
+        # Execute the base class __init__() method.
+        super(About_relax, self).__init__(*args, **kwds)
 
 
 




Related Messages


Powered by MHonArc, Updated Tue Feb 02 17:00:02 2010